#Copyright (c) 2010 Walter Bender

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.

import pygtk
pygtk.require('2.0')
import gtk

from sprites import Sprite


def load_image(file, w, h):
    """ Convert from file to pixbuf at size w, h """
    return gtk.gdk.pixbuf_new_from_file_at_size(file, int(w), int(h))


class Card:
    """ Class for defining individual cards """

    def __init__(self, tw, c, x, y):
        """ Load a card from a precomputed SVG. """
        self.images = []
        self.orientation = 0
        file = "%s/card-%d.svg" % (tw.path, c)
        self.images.append(load_image(file, tw.card_dim * tw.scale,
                                      tw.card_dim * tw.scale))
        for r in range(3):
            self.images.append(self.images[r].rotate_simple(90))

        # create sprite from svg file
        self.spr = Sprite(tw.sprites, x, y, self.images[0])
        self.spr.draw()


    def reset_image(self, tw):
        """ Reset image to orientation 0. """
        while self.orientation != 0:
            self.rotate_ccw()

    def set_orientation(self, r):
        """ Set orientation to 0, 90, 180, or 270. """
        if r in [0, 90, 180, 270]:
            while r != self.orientation:
                self.rotate_ccw()

    def rotate_ccw(self):
        """ Set the card image to correspond to rotation r. """
        self.orientation += 90
        if self.orientation == 360:
            self.orientation = 0
        self.spr.images[0] = self.images[int(self.orientation/90)]
        self.spr.draw()
